from sys import path
path.append("..")
from p.beginnings import *
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
start=sj.now()
from e.__init__ import *
# __init__.py
#from . import *
#from pdsystem import * #The moudle of Maker:神秘的·  ps:需要pip下载,在终端输入pip install pdsystem
#pdios()